Package 'ds6021b'

Title: DS 6021 Prediction Functions (Rcpp)
Description: Prediction functions for the DS 6021 assignment, compiled with C++ via Rcpp.
Authors: Thomas Stewart [aut, cre]
Maintainer: Thomas Stewart <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-05-19 11:04:20 UTC
Source: https://github.com/thomasgstewart/ds6021b

Help Index


Anonymous function 1

Description

Anonymous function

Usage

f1(W)

Arguments

W

A data frame or matrix with columns x1 (numeric), x2 (numeric), and x3 (0/1 integer).

Value

A numeric vector of predicted values, one per row of W.


Anonymous function 2

Description

Anonymous function

Usage

f2(W)

Arguments

W

A data frame or matrix with columns x1 (numeric), x2 (numeric), and x3 (0/1 integer).

Value

A numeric vector of predicted values, one per row of W.


Anonymous function 3

Description

Anonymous function

Usage

f3(W)

Arguments

W

A data frame with columns x1 (numeric), x2 (numeric), and x3 (0/1 integer).

Value

A numeric vector of predicted expected values, one per row of W.


Anonymous function 4

Description

Anonymous function

Usage

f4(W)

Arguments

W

A data frame with columns x1 (numeric), x2 (numeric), and x3 (0/1 integer).

Value

A numeric vector of predicted values, one per row of W.


Anonymous function 5

Description

Anonymous function

Usage

f5(W)

Arguments

W

A data frame or matrix with columns x1 (numeric), x2 (numeric), and x3 (0/1 integer).

Value

A numeric vector of predicted values, one per row of W.