| Title: | DS 6021 Prediction Functions (Rcpp) |
|---|---|
| Description: | Prediction functions for the DS 6021 assignment, compiled with C++ via Rcpp. |
| Authors: | Thomas Stewart [aut, cre] |
| Maintainer: | Thomas Stewart <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-19 11:04:20 UTC |
| Source: | https://github.com/thomasgstewart/ds6021b |
Anonymous function
f1(W)f1(W)
W |
A data frame or matrix with columns |
A numeric vector of predicted values, one per row of W.
Anonymous function
f2(W)f2(W)
W |
A data frame or matrix with columns |
A numeric vector of predicted values, one per row of W.
Anonymous function
f3(W)f3(W)
W |
A data frame with columns |
A numeric vector of predicted expected values, one per row of W.
Anonymous function
f4(W)f4(W)
W |
A data frame with columns |
A numeric vector of predicted values, one per row of W.
Anonymous function
f5(W)f5(W)
W |
A data frame or matrix with columns |
A numeric vector of predicted values, one per row of W.